validate

package
v1.3.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsValidDomainOrKeyword

func IsValidDomainOrKeyword(domainOrKeyword string) bool

Types

type ValidatedKeywords

type ValidatedKeywords struct {
	Keywords []string
	NewTlds  []string
}

func ValidateKeywords

func ValidateKeywords(domainsOrKeywords []string) *ValidatedKeywords

Returns a list of keywords or domains that are valid and have no duplicates. It also extracts TLDs from full domains and adds them to the config, if any.

Jump to