Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsValidDomainOrKeyword ¶
Types ¶
type ValidatedKeywords ¶
func ValidateKeywords ¶
func ValidateKeywords(domainsOrKeywords []string) *ValidatedKeywords
Returns a list of keywords or domains that are valid and have no duplicates. It also extracts TLDs from full domains and adds them to the config, if any.
Click to show internal directories.
Click to hide internal directories.